projects — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

# `projects`

## Feeds

## Forms

## Models

## Views

## I18n Library

`get_trans_handler`(i18n_type)

  Return an appropriate TransHandler class.

  TransHandler is chosen depending on the component translation type.

  It will raise an exception if the Translation type is not specified.

  Keyword arguments: i18n_type – The type of the TransHandler, used to decide the class to be returned.

      >>> print get_trans_handler('POT')
      projects.handlers.trans_handler.TransHandler

### Types

#### POT

#### Intltool

## Management commands